@@ -20,12 +20,8 @@ import httplink
 from httplink import ParsedLinks, Link, parse_link_header
 from urllib.parse import urljoin
 
-# Only relations listed below will be selected
-# Sources:
-#   https://signposting.org/conventions/
-#   https://signposting.org/FAIR/
-"""Valid Signposting link relations"""
-SIGNPOSTING=set("author collection describedby describes item cite-as type license linkset".split(" "))
+from .signpost import SIGNPOSTING
+
 
 def _filter_links_by_rel(parsedLinks:ParsedLinks, *rels:str) -> List[Link]:
     """Filter links to select from a set of relations.
@@ -71,6 +67,7 @@ class Signposting:
     .. _signposting: https://signposting.org/conventions/
     .. _FAIR: https://signposting.org/FAIR/
     """
+    #
 
     """Resource URL this is the signposting for, e.g. a HTML landing page.
     
